@@ -581,7 +581,7 @@ class Testbed:
                     return True
         return False
 
-    def _run_apt_install(self, what, prefix, recommends):
+    def _run_apt_install(self, what, prefix, recommends, ignorerc=False):
         '''actually run apt-get install'''
 
         # capture status-fd to stderr
@@ -593,7 +593,7 @@ class Testbed:
                                       '-o Debug::pkgProblemResolver=true 3>&2 2>&1' %
                                       (prefix, what, recommends)],
                                      kind='install', stderr=subprocess.PIPE)
-        if rc != 0:
+        if not ignorerc and rc != 0:
             adtlog.debug('apt-get install %s failed; status-fd:\n%s' % (what, serr))
             # check if apt failed during package download, which might be a
             # transient error, so retry
@@ -709,6 +709,13 @@ Description: satisfy autopkgtest test dependencies
                         self.check_exec(['/bin/sh', '-ec', 'rm -f /etc/apt/preferences.d/autopkgtest-default-release'])
                     continue
 
+                adtlog.warning('Test dependencies are unsatisfiable - calling '
+                               'apt install on test deps directly for further '
+                               'data about failing dependencies in test logs')
+                self._run_apt_install('--simulate ' + deps.replace(',', ''),
+                                      ' '.join(self.eatmydata_prefix),
+                                      recommends, ignorerc=True)
+
                 if shell_on_failure:
                     self.run_shell()
                 if self.enable_apt_fallback:
